@@ -1,6 +1,21 @@
 #ifndef HAS_ETREE_DEFS_H
 #define HAS_ETREE_DEFS_H
 
+/* quick check for Python/libxml2/libxslt devel setup */
+#include "Python.h"
+#ifndef PY_VERSION_HEX
+#  error the development package of Python (header files etc.) is not installed correctly
+#endif
+#include "libxml/xmlversion.h"
+#ifndef LIBXML_VERSION
+#  error the development package of libxml2 (header files etc.) is not installed correctly
+#endif
+#include "libxslt/xsltconfig.h"
+#ifndef LIBXSLT_VERSION
+#  error the development package of libxslt (header files etc.) is not installed correctly
+#endif
+
+
 /* v_arg functions */
 #define va_int(ap)     va_arg(ap, int)
 #define va_charptr(ap) va_arg(ap, char *)
@@ -51,16 +66,22 @@
 #endif
 
 /* libxml2 version specific setup */
-#include "libxml/xmlversion.h"
 #if LIBXML_VERSION < 20621
 /* (X|HT)ML_PARSE_COMPACT were added in libxml2 2.6.21 */
-#  define XML_PARSE_COMPACT  0
-#  define HTML_PARSE_COMPACT 0
+#  define XML_PARSE_COMPACT  1 << 16
+#  define HTML_PARSE_COMPACT XML_PARSE_COMPACT
 
 /* HTML_PARSE_RECOVER was added in libxml2 2.6.21 */
 #  define HTML_PARSE_RECOVER XML_PARSE_RECOVER
 #endif
 
+#if LIBXML_VERSION < 20700
+/* These were added in libxml2 2.7.0 */
+#  define XML_PARSE_OLD10      1 << 17
+#  define XML_PARSE_NOBASEFIX  1 << 18
+#  define XML_PARSE_HUGE       1 << 19
+#endif
+
 /* added to xmlsave API in libxml2 2.6.23 */
 #if LIBXML_VERSION < 20623
 #  define xmlSaveToBuffer(buffer, encoding, options)
